MockableIgnore class
Marks a single field so the generator emits null for it instead of a
faker-generated value. The consumer is expected to override the field if
they need a non-null value.
@Mockable()
class Order {
final String id;
@MockableIgnore() final ComplexThing? thing;
const Order({required this.id, this.thing});
}
Constructors
- MockableIgnore()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited